@@ -43,11 +43,15 @@ Example:
 
 import logging
 import time
-from typing import Any, Callable, Optional
+from typing import Any, Callable, Literal, Optional
 
 logger = logging.getLogger(__name__)
 
 
+# Type alias for timer backend kinds (for type hints and IDE support)
+TimerType = Literal["maya", "qt", "blender", "houdini", "thread"]
+
+
 class EventTimer:
     """Timer-based event processor for WebView.
 
@@ -89,8 +93,12 @@ class EventTimer:
         self._interval_ms = interval_ms
         self._check_validity = check_window_validity
         self._running = False
-        self._timer_impl: Optional[Any] = None  # Maya scriptJob, Qt QTimer, or Windows timer ID
-        self._timer_type: Optional[str] = None  # "maya", "qt", or "windows"
+        self._timer_impl: Optional[Any] = (
+            None  # Maya scriptJob, Qt QTimer, Blender/Houdini callbacks, or thread
+        )
+        self._timer_type: Optional["TimerType"] = (
+            None  # "maya", "qt", "blender", "houdini", "thread"
+        )
         self._close_callbacks: list[Callable[[], None]] = []
         self._tick_callbacks: list[Callable[[], None]] = []
         self._last_valid = True
@@ -271,6 +279,38 @@ class EventTimer:
         logger.debug(f"Tick callback registered: {callback.__name__}")
         return callback
 
+    def off_close(self, callback: Callable[[], None]) -> bool:
+        """Unregister a previously registered close callback.
+
+        Returns:
+            True if the callback was removed, False if it was not found.
+        """
+        try:
+            self._close_callbacks.remove(callback)
+            logger.debug(
+                f"Close callback unregistered: {getattr(callback, '__name__', repr(callback))}"
+            )
+            return True
+        except ValueError:
+            logger.debug("Close callback not found during unregistration")
+            return False
+
+    def off_tick(self, callback: Callable[[], None]) -> bool:
+        """Unregister a previously registered tick callback.
+
+        Returns:
+            True if the callback was removed, False if it was not found.
+        """
+        try:
+            self._tick_callbacks.remove(callback)
+            logger.debug(
+                f"Tick callback unregistered: {getattr(callback, '__name__', repr(callback))}"
+            )
+            return True
+        except ValueError:
+            logger.debug("Tick callback not found during unregistration")
+            return False
+
     def _try_start_maya_timer(self) -> bool:
         """Try to start Maya scriptJob timer.
 
@@ -296,7 +336,7 @@ class EventTimer:
             True if Qt timer started successfully, False otherwise
         """
         try:
-            from PySide2.QtCore import QTimer
+            from qtpy.QtCore import QTimer
 
             timer = QTimer()
             timer.setInterval(self._interval_ms)
@@ -417,7 +457,16 @@ class EventTimer:
                             # WebView not yet initialized, skip this tick
                             return
 
-                should_close = self._webview.process_events()
+                # Choose event-processing strategy based on timer backend.
+                if self._timer_type == "qt" and hasattr(self._webview, "process_events_ipc_only"):
+                    # Qt hosts (Maya, Houdini Qt, etc.) own the native event loop.
+                    # In this mode we only drain AuroraView's internal IPC queue
+                    # and rely on Qt to drive the Win32/WebView2 message pump.
+                    should_close = self._webview.process_events_ipc_only()
+                else:
+                    # Legacy/other hosts still use the full process_events() path,
+                    # which may drive the native message pump directly.
+                    should_close = self._webview.process_events()
             except RuntimeError as e:
                 if "not initialized" in str(e):
                     # WebView not yet initialized, skip this tick silently
