@@ -4,6 +4,7 @@
 
 use pyo3::prelude::*;
 use pyo3::types::PyDict;
+use pyo3::{Py, PyAny};
 use std::cell::RefCell;
 use std::rc::Rc;
 use std::sync::Arc;
@@ -517,7 +518,7 @@ impl AuroraView {
     ///     event_name (str): Name of the event to listen for
     ///     callback (callable): Python function to call when event occurs
     #[allow(clippy::useless_conversion)]
-    fn on(&self, event_name: &str, callback: PyObject) -> PyResult<()> {
+    fn on(&self, event_name: &str, callback: Py<PyAny>) -> PyResult<()> {
         tracing::info!("Registering callback for event: {}", event_name);
 
         // Store the callback in the IPC handler
@@ -711,6 +712,26 @@ impl AuroraView {
         }
     }
 
+    /// Process only internal IPC/messages without touching the host's native event loop.
+    ///
+    /// This is intended for host-driven embedding scenarios (Qt, DCC, etc.)
+    /// where the parent application owns the Win32/OS event loop and is
+    /// responsible for pumping window messages. It ONLY drains the internal
+    /// WebView message queue and respects lifecycle close requests.
+    ///
+    /// Returns:
+    ///     bool: True if the window should close, False otherwise
+    fn process_ipc_only(&self) -> PyResult<bool> {
+        let inner_ref = self.inner.borrow();
+        if let Some(ref inner) = *inner_ref {
+            Ok(inner.process_ipc_only())
+        } else {
+            Err(pyo3::exceptions::PyRuntimeError::new_err(
+                "WebView not initialized. Call show() first.",
+            ))
+        }
+    }
+
     /// Check if the window is still valid (Windows only)
     ///
     /// This method checks if the window handle is still valid.
